@@ -5,10 +5,10 @@ Created on Wed Jan  5 16:45:12 2022
 @author: Tommaso
 """
 import torch
-from .preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2,computeTrainingSetComplexity
-from loadfromtxt import loadFlatDataset
-from ppn import PointParametrizationNetwork,PointParametrizationNetworkCNN2
-from kpn import KnotPlacementNetwork
+from deep_b_spline_approximation.preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2,computeTrainingSetComplexity
+from deep_b_spline_approximation.loadfromtxt import loadFlatDataset
+from deep_b_spline_approximation.ppn import PointParametrizationNetwork,PointParametrizationNetworkCNN2
+from deep_b_spline_approximation.kpn import KnotPlacementNetwork
 
 class BSplineApproximator:
     
